@@ -102,6 +102,13 @@ class Schema(object):
                     seen.add(type_.qname)
 
     def add_documents(self, schema_nodes, location):
+        """
+
+        :type schema_nodes: List[lxml.etree._Element]
+        :type location: str
+        :type target_namespace: Optional[str]
+
+        """
         resolve_queue = []
         for node in schema_nodes:
             document = self.create_new_document(node, location)
@@ -133,6 +140,7 @@ class Schema(object):
 
         :rtype: zeep.xsd.ComplexType or zeep.xsd.AnySimpleType
 
+
         """
         qname = self._create_qname(qname)
         try:
@@ -191,16 +199,17 @@ class Schema(object):
             return 'soap-env'
         return namespace
 
-    def create_new_document(self, node, url, base_url=None):
+    def create_new_document(self, node, url, base_url=None, target_namespace=None):
         """
 
         :rtype: zeep.xsd.schema.SchemaDocument
 
         """
         namespace = node.get('targetNamespace') if node is not None else None
+        if not namespace:
+            namespace = target_namespace
         if base_url is None:
             base_url = url
-
         schema = SchemaDocument(namespace, url, base_url)
         self.documents.add(schema)
         schema.load(self, node)
@@ -377,6 +386,7 @@ class SchemaDocument(object):
         self._location = location
         self._target_namespace = namespace
         self._is_internal = False
+        self._has_empty_import = False
 
         # Containers for specific types
         self._attribute_groups = {}
