@@ -91,6 +91,8 @@ class SchemaVisitor(object):
         if not ref:
             return
 
+        ref = self._create_qname(ref)
+
         if node.tag == tags.element:
             cls = xsd_elements.RefElement
         elif node.tag == tags.attribute:
@@ -129,7 +131,12 @@ class SchemaVisitor(object):
         """
         assert node is not None
 
-        self.document._target_namespace = node.get('targetNamespace')
+        # A schema should always have a targetNamespace attribute, otherwise
+        # it is called a chameleon schema. In that case the schema will inherit
+        # the namespace of the enclosing schema/node.
+        tns = node.get('targetNamespace')
+        if tns:
+            self.document._target_namespace = tns
         self.document._element_form = node.get('elementFormDefault', 'unqualified')
         self.document._attribute_form = node.get('attributeFormDefault', 'unqualified')
 
@@ -168,6 +175,16 @@ class SchemaVisitor(object):
                 filename=self._document.location,
                 sourceline=node.sourceline)
 
+        # We found an empty <import/> statement, this needs to trigger 4.1.2
+        # from https://www.w3.org/TR/2012/REC-xmlschema11-1-20120405/#src-resolve
+        # for QName resolving.
+        # In essence this means we will resolve QNames without a namespace to no
+        # namespace instead of the target namespace.
+        # The following code snippet works because imports have to occur before we
+        # visit elements.
+        if not namespace and not location:
+            self.document._has_empty_import = True
+
         # Check if the schema is already imported before based on the
         # namespace. Schema's without namespace are registered as 'None'
         document = self.schema.documents.get_by_namespace_and_location(namespace, location)
@@ -207,7 +224,13 @@ class SchemaVisitor(object):
                 filename=self.document._location,
                 sourceline=node.sourceline)
 
-        schema = self.schema.create_new_document(schema_node, location)
+        # If the imported schema doesn't define a target namespace and the
+        # node doesn't specify it either then inherit the existing target
+        # namespace.
+        elif not schema_tns and not namespace:
+            namespace = self.document._target_namespace
+
+        schema = self.schema.create_new_document(schema_node, location, target_namespace=namespace)
         self.register_import(namespace, schema)
         return schema
 
@@ -1157,6 +1180,9 @@ class SchemaVisitor(object):
                 namespace=name.namespace, schemaLocation=name.namespace)
             self.visit_import(import_node, None)
 
+        if (not name.namespace and self.document._element_form == 'qualified' and
+            self.document._target_namespace and not self.document._has_empty_import):
+                name = etree.QName(self.document._target_namespace, name.localname)
         return name
 
     def _pop_annotation(self, items):
